@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.105-6-g4ad06e8
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.106-5-ga6331d9
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.106';
+our $VERSION = '0.107';
 
 use Moose;
 with
@@ -156,7 +156,8 @@ sub configure
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
 
     warn '[@Author::ETHER] ' . colored('You are using [ModuleBuild] as an installer, WTF?!', 'bright_red') . "\n"
-        if any { $_ eq 'ModuleBuild' } $self->installer;
+        if any { $_->isa('Dist::Zilla::Plugin::ModuleBuild') }
+            map { Dist::Zilla::Util->expand_config_package_name($_) } $self->installer;
 
     # this is better than injecting a perl prereq for 5.008, to allow MBT to
     # become more 5.006-compatible in the future without forcing the distribution to be re-released.
@@ -199,7 +200,6 @@ sub configure
 
         # Finders
         [ 'FileFinder::ByName'  => Examples => { dir => 'examples' } ],
-        [ 'FileFinder::ByName'  => ExtraTestFiles => { dir => 'xt' } ],
 
         # Gather Files
         [ 'Git::GatherDir'      => { ':version' => '2.016', do {
@@ -215,14 +215,14 @@ sub configure
 
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
             script_finder => [qw(:PerlExecFiles @Author::ETHER/Examples)] } ],
-        [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
-        [ 'Test::EOL'           => { ':version' => '0.17', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
+        [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles :ExtraTestFiles)] } ],
+        [ 'Test::EOL'           => { ':version' => '0.17', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles :ExtraTestFiles)] } ],
         'MetaTests',
         [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
         'Test::ChangesHasContent',
         [ 'Test::MinimumVersion' => { ':version' => '2.000003', max_target_perl => '5.006' } ],
-        'PodSyntaxTests',
-        'PodCoverageTests',
+        [ 'PodSyntaxTests'      => { ':version' => '5.040' } ],
+        [ 'PodCoverageTests'    => { ':version' => '5.040' } ],
         [ 'Test::PodSpelling'   => { ':version' => '2.006003', stopwords => ['irc'] } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
         [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
@@ -446,7 +446,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.106
+version 0.107
 
 =head1 SYNOPSIS
 
@@ -488,8 +488,6 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; Finders
     [FileFinder::ByName / Examples]
     dir = examples
-    [FileFinder::ByName / ExtraTestFiles]
-    dir = xt
 
 
     ;;; Gather Files
@@ -536,7 +534,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     finder = :ExecFiles
     finder = Examples
     finder = :TestFiles
-    finder = ExtraTestFiles
+    finder = :ExtraTestFiles
 
     [Test::EOL]
     :version = 0.17
@@ -544,7 +542,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     finder = :ExecFiles
     finder = Examples
     finder = :TestFiles
-    finder = ExtraTestFiles
+    finder = :ExtraTestFiles
 
     [MetaTests]
     [Test::CPAN::Changes]
@@ -554,7 +552,9 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 2.000003
     max_target_perl = 5.006
     [PodSyntaxTests]
+    :version = 5.040
     [PodCoverageTests]
+    :version = 5.040
     [Test::PodSpelling]
     :version = 2.006003
     stopwords = irc
@@ -672,7 +672,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [CheckSelfDependency]
 
     [Run::AfterBuild / .ackrc]
-    :version = 0.38
+    :version = 0.038
     quiet = 1
     run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"
     [Run::AfterBuild / .latest]
@@ -768,7 +768,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [NextRelease]
     :version = 5.033
     time_zone = UTC
-    format = %-8v  %{uyyy-MM-dd HH:mm:ss'Z'}d%{ (TRIAL RELEASE)}T
+    format = %-8v  %{yyyy-MM-dd HH:mm:ss'Z'}d%{ (TRIAL RELEASE)}T
 
     [Git::Commit / post-release commit]
     :version = 2.020
@@ -786,7 +786,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Run::AfterRelease / release complete]
     :version = 0.038
     quiet = 1
-    eval = print "release complete!\\xa"
+    eval = print "release complete!\xa"
 
     ; listed late, to allow all other plugins which do BeforeRelease checks to run first.
     [ConfirmRelease]
